#!/bin/sh

MAINTENANCE_MODE="normal"; export MAINTENANCE_MODE
PATH=$PATH":$MAINTENANCE_DIR_ROOT/bin"; export PATH
MAINTENANCE_MAKEFILE=".maintain"; export MAINTENANCE_MAKEFILE
MAINTENANCE_MAKEFILE_USER="root"; export MAINTENANCE_MAKEFILE_USER
MAINTENANCE_MAKEFILE_GROUP="root"; export MAINTENANCE_MAKEFILE_GROUP
MAINTENANCE_MAKEFILE_MODE="744"; export MAINTENANCE_MAKEFILE_MODE
