#!/bin/csh

setenv MAINTENANCE_MODE                 "normal"
setenv PATH				$PATH":$MAINTENANCE_DIR_ROOT/bin"
setenv MAINTENANCE_MAKEFILE		".maintain"
setenv MAINTENANCE_MAKEFILE_USER	"root"
setenv MAINTENANCE_MAKEFILE_GROUP	"root"
setenv MAINTENANCE_MAKEFILE_MODE	"744"
