#!/bin/sh

if [ -f $MAINTENANCE_DIR_ROOT/core/etc/config.sh ] 
then
        . $MAINTENANCE_DIR_ROOT/core/etc/config.sh
fi

if [ -f $MAINTENANCE_DIR_ROOT/addons/etc/config.sh ] 
then
        . $MAINTENANCE_DIR_ROOT/addons/etc/config.sh
fi

################################################################
# Add/Update/Remove the options here
################################################################
MAINTENANCE_PREFIX="Makefile"; export MAINTENANCE_PREFIX
MAINTENANCE_SUFFIX="maintenance"; export MAINTENANCE_SUFFIX
