#!/bin/csh

if ( -f $MAINTENANCE_DIR_ROOT/core/etc/config.csh ) then
	source $MAINTENANCE_DIR_ROOT/core/etc/config.csh
endif

if ( -f $MAINTENANCE_DIR_ROOT/addons/etc/config.csh ) then
	source $MAINTENANCE_DIR_ROOT/addons/etc/config.csh
endif

################################################################
# Add/Update/Remove the options here
################################################################
setenv MAINTENANCE_PREFIX	"Makefile"
setenv MAINTENANCE_SUFFIX	"maintenance"
